@@ -1,6 +1,7 @@
 """
 Settings used by django-python3.
 """
+from ssl import PROTOCOL_TLS
 
 from django.conf import settings
 
@@ -35,7 +36,7 @@ class LazySettings(object):
 
     LDAP_AUTH_URL = LazySetting(
         name="LDAP_AUTH_URL",
-        default="ldap://localhost:389",
+        default=["ldap://localhost:389"],
     )
 
     LDAP_AUTH_USE_TLS = LazySetting(
@@ -43,6 +44,11 @@ class LazySettings(object):
         default=False,
     )
 
+    LDAP_AUTH_TLS_VERSION = LazySetting(
+        name="LDAP_AUTH_TLS_VERSION",
+        default=PROTOCOL_TLS,
+    )
+
     LDAP_AUTH_SEARCH_BASE = LazySetting(
         name="LDAP_AUTH_SEARCH_BASE",
         default="ou=people,dc=example,dc=com",
@@ -100,6 +106,11 @@ class LazySettings(object):
         default="",
     )
 
+    LDAP_AUTH_TEST_USER_EMAIL = LazySetting(
+        name="LDAP_AUTH_TEST_USER_EMAIL",
+        default=""
+    )
+
     LDAP_AUTH_TEST_USER_PASSWORD = LazySetting(
         name="LDAP_AUTH_TEST_USER_PASSWORD",
         default="",
